

Each image shows one tissue with a sample window overlayed.
The window shows an exemplary crop seen by the model during training. Crops (and not entire tissue) are fed to the model for scalabality.
One can inspect these images to check if, e.g., the crops are not too small compared to tissue.
Also one can increase the window size for faster training, as long as GPU memory allows.

Title of each contains more info that can be used to estimate the expected (or maximum) GPU usage during training.

